"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[8171],{53382(a,p,e){e.d(p,{createWardleyServices:()=>r.J});var r=e(16760);e(50211)}}]);