"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[988],{16167(p,a,e){e.d(a,{createTreemapServices:()=>r.d});var r=e(54144);e(50211)}}]);