"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[1617],{82024(p,a,t){t.d(a,{createGitGraphServices:()=>e.b});var e=t(1999);t(50211)}}]);