"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[130],{71737(e,t,n){n.d(t,{brainfuck:()=>i});var r="><+-.,[]".split("");let i={name:"brainfuck",startState:function(){return{commentLine:!1,left:0,right:0,commentLoop:!1}},token:function(e,t){if(e.eatSpace())return null;e.sol()&&(t.commentLine=!1);var n=e.next().toString();if(-1===r.indexOf(n))return t.commentLine=!0,e.eol()&&(t.commentLine=!1),"comment";if(!0===t.commentLine)return e.eol()&&(t.commentLine=!1),"comment";if("]"===n||"["===n)return"["===n?t.left++:t.right++,"bracket";if("+"===n||"-"===n)return"keyword";if("<"===n||">"===n)return"atom";if("."===n||","===n)return"def";e.eol()&&(t.commentLine=!1)}}}}]);
//# sourceMappingURL=130.f54970adcf4563b2.js.map?v=f54970adcf4563b2