"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[7045],{34068(e,a,t){t.d(a,{mbox:()=>h});var n=["From","Sender","Reply-To","To","Cc","Bcc","Message-ID","In-Reply-To","References","Resent-From","Resent-Sender","Resent-To","Resent-Cc","Resent-Bcc","Resent-Message-ID","Return-Path","Received"],r=["Date","Subject","Comments","Keywords","Resent-Date"],i=/^[ \t]/,o=/^From /,s=RegExp("^("+n.join("|")+"): "),d=RegExp("^("+r.join("|")+"): "),c=/^[^:]+:/,m=/^[^ ]+@[^ ]+/,l=/^.*?(?=[^ ]+?@[^ ]+)/,u=/^<.*?>/,p=/^.*?(?=<.*>)/;let h={name:"mbox",startState:function(){return{inSeparator:!1,inHeader:!1,emailPermitted:!1,header:null,inHeaders:!1}},token:function(e,a){if(e.sol()){if(a.inSeparator=!1,a.inHeader&&e.match(i))return null;if(a.inHeader=!1,a.header=null,e.match(o))return a.inHeaders=!0,a.inSeparator=!0,"atom";var t,n=!1;return(t=e.match(d))||(n=!0,t=e.match(s))?(a.inHeaders=!0,a.inHeader=!0,a.emailPermitted=n,a.header=t[1],"atom"):a.inHeaders&&(t=e.match(c))?(a.inHeader=!0,a.emailPermitted=!0,a.header=t[1],"atom"):(a.inHeaders=!1,e.skipToEnd(),null)}if(a.inSeparator)return e.match(m)?"link":(e.match(l)||e.skipToEnd(),"atom");if(a.inHeader){var r="Subject"===a.header?"header":"string";if(a.emailPermitted){if(e.match(u))return r+" link";if(e.match(p))return r}return e.skipToEnd(),r}return e.skipToEnd(),null},blankLine:function(e){e.inHeaders=e.inSeparator=e.inHeader=!1},languageData:{autocomplete:n.concat(r)}}}}]);
//# sourceMappingURL=7045.efde1fec544d0e0a.js.map?v=efde1fec544d0e0a