"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[3071],{59474(t,e,n){function o(t){return RegExp("^(?:"+t.join("|")+")$","i")}n.d(e,{turtle:()=>p}),o([]);var r,i=o(["@prefix","@base","a"]),a=/[*+\-<>=&|]/;function c(t,e){var n,o,l=t.next();if(r=null,"<"==l&&!t.match(/^[\s\u00a0=]/,!1))return t.match(/^[^\s\u00a0>]*>?/),"atom";if('"'==l||"'"==l){return n=l,e.tokenize=function(t,e){for(var o,r=!1;null!=(o=t.next());){if(o==n&&!r){e.tokenize=c;break}r=!r&&"\\"==o}return"string"},e.tokenize(t,e)}if(/[{}\(\),\.;\[\]]/.test(l))return r=l,null;if("#"==l)return t.skipToEnd(),"comment";if(a.test(l))return t.eatWhile(a),null;if(":"==l)return"operator";if(t.eatWhile(/[_\w\d]/),":"==t.peek())return"variableName.special";var o=t.current();return i.test(o)?"meta":l>="A"&&l<="Z"?"comment":"keyword"}function l(t,e,n){t.context={prev:t.context,indent:t.indent,col:n,type:e}}function u(t){t.indent=t.context.indent,t.context=t.context.prev}let p={name:"turtle",startState:function(){return{tokenize:c,context:null,indent:0,col:0}},token:function(t,e){if(t.sol()&&(e.context&&null==e.context.align&&(e.context.align=!1),e.indent=t.indentation()),t.eatSpace())return null;var n=e.tokenize(t,e);if("comment"!=n&&e.context&&null==e.context.align&&"pattern"!=e.context.type&&(e.context.align=!0),"("==r)l(e,")",t.column());else if("["==r)l(e,"]",t.column());else if("{"==r)l(e,"}",t.column());else if(/[\]\}\)]/.test(r)){for(;e.context&&"pattern"==e.context.type;)u(e);e.context&&r==e.context.type&&u(e)}else"."==r&&e.context&&"pattern"==e.context.type?u(e):/atom|string|variable/.test(n)&&e.context&&(/[\}\]]/.test(e.context.type)?l(e,"pattern",t.column()):"pattern"!=e.context.type||e.context.align||(e.context.align=!0,e.context.col=t.column()));return n},indent:function(t,e,n){var o=e&&e.charAt(0),r=t.context;if(/[\]\}]/.test(o))for(;r&&"pattern"==r.type;)r=r.prev;var i=r&&o==r.type;return r?"pattern"==r.type?r.col:r.align?r.col+ +!i:r.indent+(i?0:n.unit):0},languageData:{commentTokens:{line:"#"}}}}}]);
//# sourceMappingURL=3071.14e15dfb5d34dfa1.js.map?v=14e15dfb5d34dfa1