"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[8220],{91991(e,r,t){t.d(r,{diff:()=>a});var p={"+":"inserted","-":"deleted","@":"meta"};let a={name:"diff",token:function(e){var r=e.string.search(/[\t ]+?$/);if(!e.sol()||0===r)return e.skipToEnd(),("error "+(p[e.string.charAt(0)]||"")).replace(/ $/,"");var t=p[e.peek()]||e.skipToEnd();return -1===r?e.skipToEnd():e.pos=r,t}}}}]);
//# sourceMappingURL=8220.8040f5ac945ac3a7.js.map?v=8040f5ac945ac3a7