"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[2001],{82280(t,e,n){n.d(e,{solr:()=>u});var r=/[^\s\|\!\+\-\*\?\~\^\&\:\(\)\[\]\{\}\"\\]/,o=/[\|\!\+\-\*\?\~\^\&]/,a=/^(OR|AND|NOT|TO)$/;function i(t,e){var n,u=t.next();return'"'==u?e.tokenize=function(t,e){for(var n,r=!1;null!=(n=t.next())&&(n!=u||r);)r=!r&&"\\"==n;return r||(e.tokenize=i),"string"}:o.test(u)?e.tokenize=function(t,e){return"|"==u?t.eat(/\|/):"&"==u&&t.eat(/\&/),e.tokenize=i,"operator"}:r.test(u)&&(n=u,e.tokenize=function(t,e){for(var o,u=n;(n=t.peek())&&null!=n.match(r);)u+=t.next();return(e.tokenize=i,a.test(u))?"operator":parseFloat(o=u).toString()===o?"number":":"==t.peek()?"propertyName":"string"}),e.tokenize!=i?e.tokenize(t,e):null}let u={name:"solr",startState:function(){return{tokenize:i}},token:function(t,e){return t.eatSpace()?null:e.tokenize(t,e)}}}}]);
//# sourceMappingURL=2001.c4d0a89f3e251045.js.map?v=c4d0a89f3e251045