"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[1815],{74266(e,t,s){s.r(t),s.d(t,{StyleModule:()=>r});let l="u"<typeof Symbol?"__ͼ":Symbol.for("ͼ"),o="u"<typeof Symbol?"__styleSet"+Math.floor(1e8*Math.random()):Symbol("styleSet"),i="u">typeof globalThis?globalThis:"u">typeof window?window:{};class r{constructor(e,t){this.rules=[];let{finish:s}=t||{};function l(e){return/^@/.test(e)?[e]:e.split(/,\s*/)}for(let t in e)!function e(t,o,i,r){let n=[],h=/^@(\w+)\b/.exec(t[0]),u=h&&"keyframes"==h[1];if(h&&null==o)return i.push(t[0]+";");for(let s in o){let r=o[s];if(/&/.test(s))e(s.split(/,\s*/).map(e=>t.map(t=>e.replace(/&/,t))).reduce((e,t)=>e.concat(t)),r,i);else if(r&&"object"==typeof r){if(!h)throw RangeError("The value of a property ("+s+") should be a primitive value.");e(l(s),r,n,u)}else null!=r&&n.push(s.replace(/_.*/,"").replace(/[A-Z]/g,e=>"-"+e.toLowerCase())+": "+r+";")}(n.length||u)&&i.push((s&&!h&&!r?t.map(s):t).join(", ")+" {"+n.join(" ")+"}")}(l(t),e[t],this.rules)}getRules(){return this.rules.join("\n")}static newName(){let e=i[l]||1;return i[l]=e+1,"ͼ"+e.toString(36)}static mount(e,t,s){let l=e[o],i=s&&s.nonce;l?i&&l.setNonce(i):l=new h(e,i),l.mount(Array.isArray(t)?t:[t],e)}}let n=new Map;class h{constructor(e,t){let s=e.ownerDocument||e,l=s.defaultView;if(!e.head&&e.adoptedStyleSheets&&l.CSSStyleSheet){let t=n.get(s);if(t)return e[o]=t;this.sheet=new l.CSSStyleSheet,n.set(s,this)}else this.styleTag=s.createElement("style"),t&&this.styleTag.setAttribute("nonce",t);this.modules=[],e[o]=this}mount(e,t){let s=this.sheet,l=0,o=0;for(let t=0;t<e.length;t++){let i=e[t],r=this.modules.indexOf(i);if(r<o&&r>-1&&(this.modules.splice(r,1),o--,r=-1),-1==r){if(this.modules.splice(o++,0,i),s)for(let e=0;e<i.rules.length;e++)s.insertRule(i.rules[e],l++)}else{for(;o<r;)l+=this.modules[o++].rules.length;l+=i.rules.length,o++}}if(s)0>t.adoptedStyleSheets.indexOf(this.sheet)&&(t.adoptedStyleSheets=[this.sheet,...t.adoptedStyleSheets]);else{let e="";for(let t=0;t<this.modules.length;t++)e+=this.modules[t].getRules()+"\n";this.styleTag.textContent=e;let s=t.head||t;this.styleTag.parentNode!=s&&s.insertBefore(this.styleTag,s.firstChild)}}setNonce(e){this.styleTag&&this.styleTag.getAttribute("nonce")!=e&&this.styleTag.setAttribute("nonce",e)}}}}]);
//# sourceMappingURL=1815.9db43d5ae55c2bd7.js.map?v=9db43d5ae55c2bd7